App

Struct App 

pub struct App {
    pub should_quit: bool,
    pub exit_action: Option<ExitAction>,
    /* private fields */
}
Main application state

Fields

should_quit: bool

Flag to signal application should quit

exit_action: Option<ExitAction>

Action to take when exiting (if entry was selected)

Implementations

Source

impl App

pub fn new(entries: Vec<AliasEntry>, theme: Theme) -> Self

Create a new App instance with the given entries and theme

pub fn selected_entry(&self) -> Option<&AliasEntry>

Get the currently selected entry, if any

pub fn update_visible_entries(&mut self)

Update visible entries based on current filter and search query

pub fn entries(&self) -> &[AliasEntry]

Get reference to all entries

pub fn visible_indices(&self) -> &[usize]

Get reference to visible indices

pub fn search_query(&self) -> &str

Get the search query

pub fn cursor_position(&self) -> usize

Get the cursor position

pub fn selected_index(&self) -> usize

Get the selected index

pub fn input_mode(&self) -> InputMode

Get the input mode

pub fn active_panel(&self) -> Panel

Get the active panel

pub fn filter(&self) -> EntryFilter

Get the current filter

pub fn list_scroll_offset(&self) -> usize

Get list scroll offset

pub fn description_scroll_offset(&self) -> usize

Get description scroll offset

pub fn description_max_scroll(&self) -> usize

Get description max scroll

pub fn script_scroll_offset(&self) -> usize

Get script scroll offset

pub fn script_max_scroll(&self) -> usize

Get script max scroll

pub fn pending_key(&self) -> Option<char>

Get pending key

pub fn pending_key_time(&self) -> Option<Instant>

Get pending key time

pub fn show_help(&self) -> bool

Get show help flag

pub fn help_scroll_offset(&self) -> usize

Get help scroll offset

pub fn help_max_scroll(&self) -> usize

Get help max scroll

pub fn group_mode(&self) -> GroupMode

Get group mode

pub fn sort_order(&self) -> SortOrder

Get sort order

pub fn move_up(&mut self)

Move selection up by one

pub fn move_down(&mut self)

Move selection down by one

pub fn move_top(&mut self)

Jump to the top of the active panel

pub fn move_bottom(&mut self)

Jump to the bottom of the active panel

pub fn scroll_up(&mut self, amount: usize)

Scroll the active panel up

pub fn scroll_down(&mut self, amount: usize)

Scroll the active panel down

pub fn cycle_panel(&mut self)

Cycle to the next panel (forward)

pub fn cycle_panel_backward(&mut self)

Cycle to the previous panel (backward)

pub fn cycle_filter(&mut self)

Cycle the entry type filter (forward)

pub fn cycle_filter_backward(&mut self)

Cycle the entry type filter (backward)

pub fn set_filter(&mut self, filter: EntryFilter)

Set a specific filter

pub fn enter_search_mode(&mut self)

Enter search mode

pub fn exit_search_keep_query(&mut self)

Exit search mode, keeping the current query

pub fn exit_search_clear_query(&mut self)

Exit search mode, clearing the query

Clear the search query without changing mode

pub fn set_search_query(&mut self, query: String)

Set the search query directly and update visible entries

pub fn search_insert_char(&mut self, c: char)

Insert a character at the cursor position in the search query

pub fn search_delete_char(&mut self)

Delete the character before the cursor in the search query

pub fn search_cursor_left(&mut self)

Move search cursor left

pub fn search_cursor_right(&mut self)

Move search cursor right

pub fn toggle_help(&mut self)

Toggle the help modal

pub fn help_scroll_down(&mut self)

Scroll help modal down by one line

pub fn help_scroll_up(&mut self)

Scroll help modal up by one line

pub fn help_jump_top(&mut self)

Jump to the top of the help modal

pub fn help_jump_bottom(&mut self)

Jump to the bottom of the help modal

pub fn update_help_max_scroll( &mut self, total_lines: usize, visible_lines: usize, )

Update the maximum scroll offset for help modal based on content and visible area

pub fn update_description_max_scroll( &mut self, total_lines: usize, visible_lines: usize, )

Update the maximum scroll offset for description panel based on content and visible area

pub fn update_script_max_scroll( &mut self, total_lines: usize, visible_lines: usize, )

Update the maximum scroll offset for script panel based on content and visible area

pub fn cycle_group_mode(&mut self)

Cycle to the next group mode

pub fn cycle_group_mode_backward(&mut self)

Cycle to the previous group mode

pub fn toggle_sort_order(&mut self)

Toggle sort order

pub fn is_pending_key_expired(&self) -> bool

Check if pending key has timed out (2 seconds)

pub fn clear_pending_key(&mut self)

Clear pending key state

pub fn set_pending_key(&mut self, key: char)

Set pending key with timestamp

pub fn select_entry(&mut self, action: ExitAction)

Select the current entry with the given action and exit gracefully

pub fn tick(&mut self)

Update application state (called each tick)

pub fn cycle_theme_next(&mut self)

Cycle to the next theme in alphabetical order (wraps around)

pub fn cycle_theme_prev(&mut self)

Cycle to the previous theme in alphabetical order (wraps around)

pub fn theme(&self) -> &Theme

Get reference to the current theme